summaryrefslogtreecommitdiffstats
path: root/mdoc_macro.c
diff options
context:
space:
mode:
Diffstat (limited to 'mdoc_macro.c')
-rw-r--r--mdoc_macro.c10
1 files changed, 8 insertions, 2 deletions
diff --git a/mdoc_macro.c b/mdoc_macro.c
index 570e5698..23167fb4 100644
--- a/mdoc_macro.c
+++ b/mdoc_macro.c
@@ -647,10 +647,16 @@ blk_exp_close(MACRO_PROT_ARGS)
break;
}
/* Explicit blocks close out description lines. */
if (n->tok == MDOC_Nd) {
- rew_last(mdoc, n);
+ if (later != NULL)
+ n->flags |= NODE_BROKEN | NODE_ENDED;
+ else
+ rew_last(mdoc, n);
continue;
}
@@ -647,10 +647,16 @@ blk_exp_close(MACRO_PROT_ARGS)
break;
}
- /* Explicit blocks close out description lines. */
+ /*
+ * Explicit blocks close out description lines, but
+ * even those can get broken together with a child.
+ */
if (n->tok == MDOC_Nd) {